@@ -170,10 +170,6 @@ _VTE_PUBLIC
 void vte_terminal_feed_child(VteTerminal *terminal,
                              const char *text,
                              gssize length) _VTE_GNUC_NONNULL(1);
-_VTE_PUBLIC
-void vte_terminal_feed_child_binary(VteTerminal *terminal,
-                                    const guint8 *data,
-                                    gsize length) _VTE_GNUC_NONNULL(1);
 
 /* Copy currently-selected text to the clipboard, or from the clipboard to
  * the terminal. */
